@@ -8,7 +8,7 @@ from typing import List, Mapping, Optional, Union, Dict, BinaryIO
 import requests
 import time
 from PIL import Image
-from annotell.auth.authsession import AuthSession, DEFAULT_HOST as DEFAULT_AUTH_HOST
+from annotell.auth.authsession import FaultTolerantAuthRequestSession, DEFAULT_HOST as DEFAULT_AUTH_HOST
 
 from . import input_api_model as IAM
 
@@ -39,7 +39,7 @@ class InputApiClient:
         """
 
         self.host = host
-        self.oauth_session = AuthSession(host=auth_host, auth=auth)
+        self._auth_req_session = FaultTolerantAuthRequestSession(host=auth_host, auth=auth)
         self.headers = {
             "Accept-Encoding": "gzip",
             "Accept": "application/json"
@@ -55,7 +55,7 @@ class InputApiClient:
 
     @property
     def session(self):
-        return self.oauth_session.session
+        return self._auth_req_session
 
     @staticmethod
     def _raise_on_error(resp: requests.Response) -> requests.Response:
@@ -180,13 +180,27 @@ class InputApiClient:
         if (input_list_id is not None):
             input_request['inputListId'] = input_list_id
 
-        print(input_request)
         request_url = self._resolve_request_url(resource_path, project, batch)
         resp = self.session.post(request_url, json=input_request, headers=headers)
         json_resp = self._unwrap_enveloped_json(self._raise_on_error(resp).json())
         if not dryrun:
             return IAM.CreateInputJobResponse.from_json(json_resp)
 
+    def get_inputs(self, project_id: int, invalidated: bool) -> List[IAM.Input]:
+        """
+        Gets inputs for project, with option to filter for invalidated inputs
+
+        :param project_id: Project id to filter
+        :param invalidated: Returns invalidated inputs if True, otherwise valid inputs
+        :return List: List of Inputs
+        """
+
+        url = f"{self.host}/v1/inputs?projectId={project_id}&invalidated={invalidated}"
+        resp = self.session.get(url, headers=self.headers)
+        json_resp = self._unwrap_enveloped_json(self._raise_on_error(resp).json())
+        return [IAM.Input.from_json(js) for js in json_resp]
+
+
     def count_inputs_for_external_ids(self, external_ids: List[str]) -> Dict[str, int]:
         """
         For each external id, returns a count of how many inputs exists with that external id.
@@ -428,11 +442,11 @@ class InputApiClient:
         resp = self.session.get(url, headers=self.headers)
         return self._raise_on_error(resp).json()
 
-    def invalidate_inputs(self, input_ids: List[int], invalidated_reason: IAM.InvalidatedReasonInput):
+    def invalidate_inputs(self, input_ids: List[str], invalidated_reason: IAM.InvalidatedReasonInput):
         """
         Invalidates inputs, and removes them from all input lists
 
-        :param input_ids: The input ids to invalidate
+        :param input_ids: The input internal ids to invalidate
         :param invalidated_reason: An Enum describing why inputs were invalidated
         :return InvalidatedInputsResponse: Class containing what inputs were invalidated
         """
@@ -490,6 +504,18 @@ class InputApiClient:
         json_resp = self._raise_on_error(resp).json()
         return [IAM.InputList.from_json(js) for js in json_resp]
 
+    def publish_batch(self, project: str, batch: str) -> IAM.InputBatch:
+        """
+        Publish input batch, marking the input batch ready for annotation.
+        After publishing, no more inputs can be added to the input batch
+
+        :return InputBatch: Updated input batch
+        """
+        url = f"{self.host}/v1/inputs/project/{project}/batch/{batch}/publish"
+        resp = self.session.post(url, headers=self.headers)
+        json_resp = self._unwrap_enveloped_json(self._raise_on_error(resp).json())
+        return IAM.InputBatch.from_json(json_resp)
+
     def get_calibration_data(self, id: Optional[int] = None, external_id: Optional[str] = None
                              ) -> Union[List[IAM.CalibrationNoContent], List[IAM.CalibrationWithContent]]:
         """
