@@ -1,9 +1,15 @@
 """API MODEL."""
 from typing import List, Mapping, Dict, Optional, Union
-from enum import Enum
 from datetime import datetime
 import dateutil.parser
 
+from .model.abstract_models import RequestCall, Response
+from .model.enums import InputBatchStatus, InvalidatedReasonInput
+# To preserve old import statements
+from .model.enums import CameraType
+from .model.calibration import CameraProperty
+from .model.calibration_legacy import CameraCalibration, LidarCalibration
+from .model.calibration import CameraCalibrationExplicit, LidarCalibrationExplicit
 ENVELOPED_JSON_TAG = "data"
 
 
@@ -11,25 +17,6 @@ def ts_to_dt(date_string: str) -> datetime:
     return dateutil.parser.parse(date_string)
 
 
-class RequestCall:
-    def to_dict(self) -> dict:
-        raise NotImplementedError
-
-
-class InvalidatedReasonInput(str, Enum):
-    BAD_CONTENT = "bad-content"
-    SLAM_RECORRECTION = "slam-rerun"
-    DUPLICATE = "duplicate"
-    INCORRECTLY_CREATED = "incorrectly-created"
-
-
-class InputBatchStatus(str, Enum):
-    CREATED = 'created'
-    OPEN = 'open'
-    READY = 'ready'
-    INPROGESS = 'in-progress'
-    COMPLETED = 'completed'
-
 #
 # Request Calls
 #
@@ -99,82 +86,8 @@ class PointCloudsWithImages(RequestCall):
                     pointClouds=[pc.to_dict() for pc in self.point_clouds])
 
 
-class CameraType(str, Enum):
-    PINHOLE = "pinhole"
-    FISHEYE = "fisheye"
-    KANNALA = "kannala"
-
-
-class CameraProperty(RequestCall):
-    def __init__(self, camera_type: CameraType):
-        self.camera_type = camera_type
-
-    def to_dict(self):
-        return {
-            "camera_type": self.camera_type
-        }
-
-
-class CameraCalibration(RequestCall):
-    def __init__(self, position: List[float], rotation_quaternion: List[float],
-                 camera_matrix: List[float], camera_properties: CameraProperty,
-                 distortion_coefficients: List[float], image_height: int, image_width: int,
-                 undistortion_coefficients: Optional[List[float]]):
-
-        self.position = position
-        self.rotation_quaternion = rotation_quaternion
-
-        self.camera_matrix = camera_matrix
-        self.camera_properties = camera_properties
-        self.distortion_coefficients = distortion_coefficients
-        self.image_height = image_height
-        self.image_width = image_width
-        self.undistortion_coefficients = undistortion_coefficients
-
-        assert(len(position) == 3)
-        assert(len(rotation_quaternion) == 4)
-        assert(len(camera_matrix) == 9)
-
-        if camera_properties.camera_type == CameraType.KANNALA:
-            assert(undistortion_coefficients is not None)
-            assert(len(distortion_coefficients) == 4 and len(undistortion_coefficients) == 4)
-        else:
-            assert(len(distortion_coefficients) == 5)
-
-    def to_dict(self):
-        base = {
-            "position": self.position,
-            "rotation_quaternion": self.rotation_quaternion,
-            "camera_matrix": self.camera_matrix,
-            "camera_properties": self.camera_properties.to_dict(),
-            "distortion_coefficients": self.distortion_coefficients,
-            "image_height": self.image_height,
-            "image_width": self.image_width
-        }
-
-        if self.undistortion_coefficients is not None:
-            base["undistortion_coefficients"] = self.undistortion_coefficients
-
-        return base
-
-
-class LidarCalibration(RequestCall):
-    def __init__(self, position: List[float], rotation_quaternion: List[float]):
-        self.position = position
-        self.rotation_quaternion = rotation_quaternion
-
-        assert(len(position) == 3)
-        assert(len(rotation_quaternion) == 4)
-
-    def to_dict(self):
-        return {
-            "position": self.position,
-            "rotation_quaternion": self.rotation_quaternion
-        }
-
-
 class Calibration(RequestCall):
-    def __init__(self, calibration_dict: Dict[str, Union[CameraCalibration, LidarCalibration]]):
+    def __init__(self, calibration_dict: Dict[str, Union[CameraCalibration, CameraCalibrationExplicit, LidarCalibrationExplicit, LidarCalibration]]):  # noqa:E501
         self.calibration_dict = calibration_dict
 
     def to_dict(self):
@@ -368,12 +281,6 @@ class Trajectory(RequestCall):
 #
 
 
-class Response:
-    @staticmethod
-    def from_json(js: dict):
-        raise NotImplementedError
-
-
 class CalibrationNoContent(Response):
     def __init__(self, id: int, external_id: str, created: datetime):
         self.id = id
@@ -596,24 +503,30 @@ class Data(Response):
 
 
 class Input(Response):
-    def __init__(self, internal_id: Optional[str], external_id: Optional[str], input_type: str):
+    def __init__(self, internal_id: Optional[str], external_id: Optional[str], input_type: str, invalidated: Optional[str], invalidated_reason: Optional[InvalidatedReasonInput]):
         self.internal_id = internal_id
         self.external_id = external_id
         self.input_type = input_type
+        self.invalidated = invalidated
+        self.invalidated_reason = invalidated_reason
 
     @staticmethod
     def from_json(js: dict):
         return Input(
             js.get("internalId"),
             js.get("externalId"),
-            js["inputType"]
+            js["inputType"],
+            js["invalidated"],
+            js["invalidatedReason"]
         )
 
     def __repr__(self):
         return f"<Input(" + \
             f"internal_id={self.internal_id}, " + \
             f"external_id={self.external_id}, " + \
-            f"inpyt_type={self.input_type})>"
+            f"external_id={self.input_type}, " + \
+            f"external_id={self.invalidated}, " + \
+            f"input_type={self.invalidated_reason})>"
 
 
 class InvalidatedInputsResponse(Response):
